```{toctree}
   :hidden:

   Home <self>
   Tutorial <tutorial/index>
   Examples <examples/index>
   About <about>
```

![MNELAB screenshots](https://raw.githubusercontent.com/cbrnr/mnelab/main/mnelab.png)

MNELAB is a graphical user interface (GUI) for [MNE-Python](https://github.com/mne-tools/mne-python), a package for EEG/MEG analysis.

Read the [**tutorial**](./tutorial/index) for installation instructions and first steps. The [**examples**](./examples/index) showcase MNELAB for common use cases.
